@@ -133,7 +133,7 @@ class MySQLConnector(Database):
     def __init__(self):
         Database.__init__(self)
         
-    def load_data_from_list(self, table, array, step=10000, replace=False, ignore=True, truncate=False):
+    def load_data_from_list(self, table, array, step=10000, ignore=True, delete=True, **kwargs):
         try:
             desc = self.desc_table(table)
         except mysql.connector.errors.ProgrammingError as err:
@@ -189,6 +189,7 @@ class MySQLConnector(Database):
                         else:
                             if isinstance(pk, str):
                                 try:
+                                    import json
                                     obj = json.loads(pk)
                                     return
                                 except:
@@ -314,6 +315,7 @@ class MySQLConnector(Database):
             if m:
                 char_length[i] = int(m[1])           
                 
+        truncate = kwargs.get('truncate')
         def create_csv(lines, step):
             import tempfile
             folder = tempfile.gettempdir()
@@ -373,15 +375,25 @@ class MySQLConnector(Database):
                         
                         if args:
                             if has_training_field and len(args) < len(desc):
-                                args.append(str(random.randint(0, 1)))               
-                            print('\t'.join(args), file=file)
+                                args.append(str(random.randint(0, 1)))
+
+                            for i, arg in enumerate(args):
+                                if '\t' in arg or '\n' in arg:
+                                    print(f'error detected: tab or newline found in Field: {desc[i][0]}')
+                                    for (Field, Type, Null, Key, *_), arg in zip(desc, args):
+                                        if Key:
+                                            print(Field, '=', arg)
+                                    print()
+                                    break
+                            else:
+                                print('\t'.join(args), file=file)
                             
                 std.eol_convert(csv)
                 yield csv
                 
         rowcount = 0
         for csv in create_csv(array, step):
-            rowcount += self.load_data_from_csv(table, csv, delete=True, replace=replace, ignore=ignore)
+            rowcount += self.load_data_from_csv(table, csv, delete=delete, ignore=ignore, **kwargs)
         return rowcount
 
     def load_data(self, table, *args, **kwargs):
@@ -428,12 +440,12 @@ class MySQLConnector(Database):
                     array.append(obj)
             return self.load_data(table_name, array)
 
-    def load_data_from_csv(self, table, csv, delete=False, replace=False, ignore=False):
+    def load_data_from_csv(self, table, csv, delete=True, **kwargs):
         start = time.time()
         csv = csv.replace('\\', '/')
-        if replace:
+        if replace := kwargs.get('replace'):
             sql = 'load data local infile "%s" replace into table %s character set utf8mb4' % (csv, table)
-        elif ignore:
+        elif ignore := kwargs.get('ignore'):
             sql = 'load data local infile "%s" ignore into table %s character set utf8mb4' % (csv, table)
         else:
             sql = 'load data local infile "%s" into table %s character set utf8mb4' % (csv, table)
