@@ -903,6 +903,11 @@ def kill():
     else:
         os.system(f"taskkill /F /pid {pid}")
 
+def list_to_tuple(array):
+    if isinstance(array, list):
+        return tuple(list_to_tuple(a) for a in array)
+    return array
+
 if __name__ == '__main__':
     arr = [*range(10)]
     former, latter = array_split(arr, slice(-2, -8, -2))
