@@ -23,8 +23,11 @@ class Text:
         try:
             self.file = open(path, mode=mode, encoding=encoding)
         except PermissionError as e:
-            print("error message printed in std.file:", e)
-            raise e
+            try:
+                self.file = open(path, mode='r', encoding=encoding)
+            except PermissionError as e:
+                print("error message printed in std.file:", e)
+                raise e
         except FileNotFoundError:
             createNewFile(path)
             self.file = open(path, "w+", encoding=encoding)
@@ -325,3 +328,18 @@ class GzipFile:
             return next(self)
         except StopIteration:
             return ''    
+
+
+def read_excel(file):
+    try:
+        from xlrd import open_workbook
+    except:
+        print('pip install xlrd==1.2.0')
+
+    for sheet in open_workbook(file).sheets():
+        name = sheet.name
+        for i in range(sheet.nrows):
+            array = sheet.row_values(i)
+            for j in range(sheet.ncols):
+                yield name, i, j, array[j]
+        
\ No newline at end of file
