@@ -78,13 +78,13 @@ def availableGPU():
 
     print('ids =', ids)
 
-    if gpu_count := os.environ.get('gpu_count'):
-        gpu_count = int(gpu_count)
-        print('gpu_count =', gpu_count)
+    if num_gpus := os.environ.get('num_gpus'):
+        num_gpus = int(num_gpus)
+        print('num_gpus =', num_gpus)
         ids = [id for id in ids if not os.path.exists(f'cuda:{id}.lock')]
 
         device_id = []
-        for _ in range(gpu_count):
+        for _ in range(num_gpus):
             index = selcect_single_free_device(ids)
             if index >= 0:
                 device_id.append(ids.pop(index))
@@ -212,7 +212,7 @@ class KerasModel:
     @staticmethod
     def numpify_y(arr):
         if KerasModel.is_integer(arr):
-            return numpify(arr, mask_value=-1, dtype=np.int64)
+            return numpify(arr, mask_value=-100, dtype=np.int64)
         return numpify(arr)
 
     def __init__(self, **kwargs):
@@ -787,32 +787,31 @@ class EpochRunner:
 
         return history
 
+    def predict_single(self, batch):
+        if isinstance(self.device, torch.device): 
+            if isinstance(batch, tuple):
+                batch = [*batch]
+
+            for i, data in enumerate(batch):
+                if data is None:
+                    continue
+
+                if isinstance(data, (list, tuple)):
+                    data = [data.to(self.device) for data in data]
+                else:
+                    if data.dtype == torch.int:
+                        data = data.long()
+                    data = data.to(self.device)
+                batch[i] = data
+
+        with torch.no_grad():
+            return self.batch_runner(*batch)
+
     def predict(self, dataloader):
-        output = []
         if len(dataloader) > 1:
             from tqdm import tqdm
             dataloader = tqdm(dataloader)
-        for batch in dataloader:
-            if isinstance(self.device, torch.device): 
-                if isinstance(batch, tuple):
-                    batch = [*batch]
-
-                for i, data in enumerate(batch):
-                    if data is None:
-                        continue
-
-                    if isinstance(data, (list, tuple)):
-                        data = [data.to(self.device) for data in data]
-                    else:
-                        if data.dtype == torch.int:
-                            data = data.long()
-                        data = data.to(self.device)
-                    batch[i] = data
-
-            with torch.no_grad():
-                output.append(self.batch_runner(*batch))
-                   
-        return torch.vstack(output)
+        return torch.vstack([self.predict_single(batch) for batch in dataloader])
 
     @computed
     def device(self):
