@@ -8,24 +8,27 @@ def detect_language(text):
     cn = 0
     en = 0
 
-    for ch in text:
+    mid = len(text) / 2
+    for i, ch in enumerate(text):
+        position_weight = (i - mid + 0.01) / mid
+        position_weight = position_weight ** 2
         if re.compile('\p{Letter}').match(ch):
             if re.compile('\p{Han}').match(ch):
-                cn += 2
+                cn += 8 * position_weight
             else:
-                en += 1    
+                en += position_weight
 
         elif re.compile('\p{Number}').match(ch):
             if ord(ch) > 256:
-                cn += 2
+                cn += 2 * position_weight
             else:
-                en += 1
+                en += position_weight
 
         elif re.compile('\p{Punctuation}').match(ch):
             if ord(ch) > 256:
-                cn += 2
+                cn += 2 * position_weight
             else:
-                en += 1
+                en += position_weight
 
         elif re.compile('\p{Symbol}').match(ch):
             ...
